# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid debuginfo files getting into the manifest
%global debug_package %{nil}

Name:		perl-Test-Perl-Critic
Summary:	Use Perl::Critic in test programs
Version:	1.04
Release:	19.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Perl-Critic
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Perl-Critic-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Module::Build) >= 0.40
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(English)
BuildRequires:	perl(Perl::Critic) >= 1.105
BuildRequires:	perl(Perl::Critic::Utils) >= 1.105
BuildRequires:	perl(Perl::Critic::Violation) >= 1.105
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder) >= 0.88
BuildRequires:	perl(warnings)
# Optional Runtime
BuildRequires:	perl(MCE::Grep) >= 1.827
# Test Suite
BuildRequires:	perl(Test::More)
# Extra Tests
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(MCE::Grep) >= 1.827
Requires:	perl(Perl::Critic) >= 1.105
Requires:	perl(Perl::Critic::Utils) >= 1.105
Requires:	perl(Perl::Critic::Violation) >= 1.105
Requires:	perl(Test::Builder) >= 0.88

# Remove underspecified dependencies
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(Perl::Critic\\)$
%global __requires_exclude %{__requires_exclude}|^perl\\(Perl::Critic::Utils\\)$
%global __requires_exclude %{__requires_exclude}|^perl\\(Perl::Critic::Violation\\)$
%global __requires_exclude %{__requires_exclude}|^perl\\(Test::Builder\\)$

%description
Test::Perl::Critic wraps the Perl::Critic engine in a convenient
subroutine suitable for test programs written using the Test::More
framework. This makes it easy to integrate coding-standards enforcement
into the build process. For ultimate convenience (at the expense of some
flexibility), see the criticism pragma.

%prep
%setup -q -n Test-Perl-Critic-%{version}

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
./Build test
./Build test --test_files="$(echo $(find xt/ -name '*.t'))"

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Perl::Critic.3*

%changelog
* Tue May  9 2023 Paul Howarth <paul@city-fan.org> - 1.04-19
- Use SPDX-format license tag

* Fri Dec 31 2021 Paul Howarth <paul@city-fan.org> - 1.04-14
- Use %%license unconditionally
- No spell checking done in package build

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 1.04-5
- Perl 5.30 rebuild

* Tue Mar 27 2018 Paul Howarth <paul@city-fan.org> - 1.04-1
- Update to 1.04
  - Sped up critic_ok() by 4x by not recreating a Perl::Critic object over and
    over (GH#10)
  - Now requires Test::Builder~0.88 or later to support the done_testing()
    method (GH#2)
  - Now requires MCE 1.827 to deal with problems running under taint mode (GH#6)
- This release by PETDANCE → update source URL
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Wed Oct  5 2016 Paul Howarth <paul@city-fan.org> - 1.03-5
- BR: perl-generators where available
- Stop shipping the tests

* Wed Feb  4 2015 Paul Howarth <paul@city-fan.org> - 1.03-1
- Update to 1.03
  - all_critic_ok() will now run tests in parallel over multiple cores, so if
    you have 8 cores, your Perl::Critic tests could run 8x faster; however,
    the actual performance depends on the size and shape of your code base and
    your Perl::Critic configuration
  - If you're using the critic_ok() function directly (perhaps because you want
    more control over which files are tested) then you won't see any
    performance boost; I recommend gathering your list of files first, and then
    passing the list to all_critic_ok()
  - The deprecated function all_code_files() has now been removed from
    Test::Perl::Critic; use Perl::Critic::Utils::all_perl_files() instead
- Classify buildreqs by usage

* Tue Sep 16 2014 Paul Howarth <paul@city-fan.org> - 1.02-14
- Use %%license where possible

* Fri Jul 13 2012 Paul Howarth <paul@city-fan.org> - 1.02-8
- Perl 5.16 rebuild

* Wed Mar 21 2012 Paul Howarth <paul@city-fan.org> - 1.02-7
- Drop spec file elements only needed for support for distributions prior to
  FC-3, which we could never support anyway given that Perl::Critic requires
  Exporter ≥ 5.58:
  - Don't need to define %%{perl_vendorlib}
  - Don't need to run test suite with LC_ALL=C
- BR: perl(Carp), perl(English), perl(Perl::Critic::Utils) ≥ 1.105,
  perl(Perl::Critic::Violation) ≥ 1.105, perl(Test::Builder), perl(Test::More)
- Add obsoletes/provides for old Fedora tests subpackage, and include tests
  as documentation (if we have %%{perl_default_filter} to get rid of the
  resulting doc-file dependencies)
- Add explicit versioned requires for Perl::Critic*

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 1.02-5
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.02-3
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 1.02-2
- Fix dist tag for RHEL-6 Beta

* Tue Feb  2 2010 Paul Howarth <paul@city-fan.org> - 1.02-1
- Import from Fedora
- Update to 1.02
  - Documentation changes
  - META.yml "enhancements"
  - Moved author tests out of the way of normal testing
  - Now requires Perl-Critic version 1.105 or newer
- Re-enable test suite

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1.01-8
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.01-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.01-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.01-5
- Rebuild for perl 5.10 (again)

* Tue Jan 15 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.01-4
- Disable tests, take out patch, doesn't fix test failures

* Tue Jan 15 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.01-3
- Patch for test failure

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.01-2
- Rebuild for new perl

* Sat Jan 27 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.01-1
- Update to 1.01

* Sun Nov 12 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.08-1
- Update to 0.08

* Sat Sep 23 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.07-1
- First build
